@@ -6,6 +6,10 @@
  * Functions specific to all POSIX compliant platforms.
  */
 
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE 1
+#endif
+
 #include <errno.h>
 #include <stdlib.h>
 #include <sys/resource.h>
